@@ -249,7 +249,7 @@ class MDS:
             default_bucket
         )
 
-    def call_model_convert_path_status(self, data: Dict[str, Any]) -> None:
+    def call_model_convert_path_status(self, data: Dict[str, Any]) -> Dict[str, Any]:
         """callback modelConvert path and status.
 
         Arguments:
@@ -267,7 +267,7 @@ class MDS:
         info = self._x_api.call_model_convert_path_status(data)
         return info
 
-    def call_model_test_status(self, data: Dict[str, Any]) -> None:
+    def call_model_test_status(self, data: Dict[str, Any]) -> Dict[str, Any]:
         """callback modelTest status.
 
         Arguments:
@@ -284,7 +284,7 @@ class MDS:
         info = self._x_api.call_model_test_status(data)
         return info
 
-    def call_model_test_result_content(self, data: Dict[str, Any]) -> None:
+    def call_model_test_result_content(self, data: Dict[str, Any]) -> Dict[str, Any]:
         """callback modelTestResult content..
 
         Arguments:
@@ -297,3 +297,27 @@ class MDS:
             raise InvalidParamsError(message="mid not blank")
         info = self._x_api.call_model_test_result_content(data)
         return info
+
+    def send_notice(
+            self,
+            title: str,
+            status: int,
+            msg: str,
+            usernames: Optional[List[str]] = None
+    ) -> Dict[str, Any]:
+        """Send notice to metaloop users
+
+        Arguments:
+            title: notice type.
+            status: project status you want to notice, 1 is succeed , 2 is failed , 3 is common.
+            msg: the msg you want to notice.
+            usernames: the users you want to notice, if usernames is nil , then notice will send to yourself.
+
+        """
+        info = self._x_api.send_notice(title, status, msg, usernames)
+        return info
+    
+    class NOTICE:
+        SUCCEED = 1
+        FAILED = 2
+        COMMON = 3
