@@ -214,7 +214,6 @@ class X_API:
 
         return path_root
 
-
     def get_authorized_s3_config(
             self,
             name: Optional[str] = "",
@@ -253,6 +252,16 @@ class X_API:
 
         return info
 
+    def merge_dataset(
+            self,
+            dataset_id: str,
+            merged_dataset_ids: List[str]
+    ) -> None:
+        post_data: Dict[str, Any] = {
+            "dataset_id": merged_dataset_ids
+        }
+        self._client.open_api_do("POST", "merge", dataset_id, json=post_data)
+
     def post_import(
             self,
             dataset_id: str,
@@ -342,21 +351,37 @@ class X_API:
 
     def call_model_convert_path_status(
             self,
-            post_data: str
+            post_data: Dict[str, Any]
     ) -> Dict[str, Any]:
         response = self._client.open_api_do("PUT", "model_convert/path/callback", "", json=post_data).json()
         return response
 
     def call_model_test_status(
              self,
-             post_data: str
+             post_data: Dict[str, Any]
     ) -> Dict[str, Any]:
         response = self._client.open_api_do("PUT", "model_test/status/callback", "", json=post_data).json()
         return response
 
     def call_model_test_result_content(
             self,
-            post_data: str
+            post_data: Dict[str, Any]
     ) -> Dict[str, Any]:
         response = self._client.open_api_do("PUT", "model_test_result/content/callback", "", json=post_data).json()
         return response
+    
+    def send_notice(
+            self,
+            title: str,
+            status: int,
+            msg: str,
+            usernames: Optional[List[str]] = None
+    ) -> Dict[str, Any]:
+        data = {}
+        data["title"] = title
+        data["status"] = status
+        data["msg"] = msg
+        if usernames:
+            data["usernames"] = usernames
+        response = self._client.open_api_do("POST", "notice", "", json=data).json()
+        return response
